@@ -18,17 +18,7 @@ class VkAddon:
 	def type(self):
 		try:
 			if self.event['object']['from_id'] > 0:
-				if self.event['object']['action']['type'] == 'chat_invite_user':
-					return 'chat_invite_user'
-
-				if self.event['object']['action']['type'] == 'chat_invite_user_by_link':
-					return 'chat_invite_user_by_link'
-
-				elif self.event['object']['action']['type'] == 'chat_kick_user':
-					return 'chat_kick_user'
-
-				else:
-					return self.event['object']['action']['type']
+				return self.event['object']['action']['type']
 
 		except KeyError:
 			if self.event['type'] == 'message_new':				
@@ -50,5 +40,8 @@ class VkAddon:
 	def text(self):
 		return self.event['object']['text']
 
+	def chat_id(self):
+		return self.event['object']['peer_id'] - 2000000000
+
 
 
